pub fn https_connector() -> Result<Connector>Expand description
Build an HTTPS connector using rustls with the platform’s native roots.
Errors
Returns Error::Auth when the native root certificate store cannot be
loaded.
pub fn https_connector() -> Result<Connector>Build an HTTPS connector using rustls with the platform’s native roots.
Returns Error::Auth when the native root certificate store cannot be
loaded.