pub fn project(document: &Document) -> ProjectionExpand description
Project an org document into ordered Docs requests and a position map.
pub fn project(document: &Document) -> ProjectionProject an org document into ordered Docs requests and a position map.